Module MockToken

Module MockToken 

Module containing a contract’s types and functions.

contract MockToken {
    function mint(address account, uint256 amount) public { <stmts> }
    function buy(address token, uint256 amount) public { <stmts> }
}

Structs

buyCall
Function with signature buy(address,uint256) and selector 0xcce7ec13.
buyReturn
Container type for the return parameters of the buy(address,uint256) function.
mintCall
Function with signature mint(address,uint256) and selector 0x40c10f19.
mintReturn
Container type for the return parameters of the mint(address,uint256) function.

Enums

MockTokenCalls
Container for all the MockToken function calls.