pub async fn get_test_policy_task_data(
rpc_url: &str,
policy_client_address: Address,
) -> PolicyTaskDataExpand description
Get the test policy task data with proper attestation
pub async fn get_test_policy_task_data(
rpc_url: &str,
policy_client_address: Address,
) -> PolicyTaskDataGet the test policy task data with proper attestation